@@ -1,3 +1,6 @@
+#ifndef COMPASS_H
+#define COMPASS_H
+
 /*
   GPSJinni - show raw data from the GPS subsystem.
   Copyright (C) 2009  Tim Teulings
@@ -37,5 +40,10 @@ public:
   void Draw(int x, int, size_t w, size_t h);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
+
+  static Compass* Create(Lum::Base::Model* model,
+                         bool horizontalFlex=false,
+                         bool verticalFlex=false);
 };
 
+#endif
