@@ -858,6 +858,7 @@ private:
   Lum::Model::StringRef    latitude;
   Lum::Model::StringRef    longitude;
   Lum::Model::StringRef    altitude;
+  Lum::Model::DoubleRef    speedValue;
   Lum::Model::StringRef    speed;
   Lum::Model::StringRef    track;
   Lum::Model::DoubleRef    direction;
@@ -1052,6 +1053,7 @@ public:
     latitude(new Lum::Model::String(L"")),
     longitude(new Lum::Model::String(L"")),
     altitude(new Lum::Model::String(L"")),
+    speedValue(new Lum::Model::Double()),
     speed(new Lum::Model::String(L"")),
     track(new Lum::Model::String(L"")),
     direction(new Lum::Model::Double()),
@@ -1182,7 +1184,7 @@ public:
 
     multiView.AddView(Lum::Def::MultiView::View(2,
                                                 Lum::Def::Desc(L"Speed"),
-                                                Speed::Create(direction,true,true)));
+                                                Speed::Create(speedValue,true,true)));
 
     multiView.AddView(Lum::Def::MultiView::View(3,
                                                 Lum::Def::Desc(L"Compass"),
@@ -1900,9 +1902,11 @@ public:
         s+=L"m/s";
       }
 
+      speedValue->Set(data.GetSpeed());
       speed->Set(s);
     }
     else {
+      speedValue->SetNull();
       speed->SetNull();
     }
 
